"""Detection with Haar cascade and filtering with Non-Maxima Supression (NMS)."""

from .version import __version__
import cv2


class Detector(cv2.CascadeClassifier):
    """Extend the opencv haar-cascade detector, by adding the method detectAndFilter."""
    
    def detectAndFilter(self, 
                        image, 
                        scaleFactor,
                        minSize, maxSize, 
                        score_threshold, 
                        overlap_threshold, 
                        nObjects=float("inf")):
        """Detect object using trained cascade and filter overlapping detections with NMS."""
        # Initial detection
        bboxes, rejectLevel, levelWeights = self.detectMultiScale3(image,
                                                                   scaleFactor,
                                                                   minNeighbors = 1,
                                                                   minSize = minSize,
                                                                   maxSize = maxSize,
                                                                   outputRejectLevels = True)
        # BBoxes formatting and NMS
        scores = levelWeights[:,0]
        indexes = cv2.dnn.NMSBoxes(bboxes.tolist(), scores, score_threshold, overlap_threshold)
        
        # final list of hits
        nBoxes = len(indexes)
        finalScores = [None] * nBoxes 
        finalBoxes  = [None] * nBoxes
        
        for i, index in enumerate(indexes[:,0]):
            finalBoxes [i] = bboxes[index].tolist()
            finalScores[i] = scores[index]
        
        # Return up to nObjects if mentioned
        if nObjects != float("inf"):
            finalBoxes  = finalBoxes[:nObjects]
            finalScores = finalScores[:nObjects]
        
        return finalBoxes, finalScores


import setuptools

with open("README.md", "r") as fh:
	long_description = fh.read()

# Read version from MTM/version.py
exec(open('haarcascade/version.py').read())


setuptools.setup(
	name="haar-cascade-nms",
	version=__version__,
	author="Laurent Thomas",
	author_email="laurent132.thomas@laposte.net",
	description="Extend opencv haar-cascade detector to filter detections with Non-Maxima Suppression (NMS)",
	long_description=long_description,
	long_description_content_type="text/markdown",
	keywords="object-recognition object-localization cascade-detectors opencv",
	url="https://github.com/LauLauThom/haar-cascade-nms",
	packages=["haarcascade"],
	install_requires=['opencv-python-headless'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
		"Operating System :: OS Independent",
		"Topic :: Scientific/Engineering :: Image Recognition",
		"Intended Audience :: Science/Research"		
	]
)